@@ -60,8 +60,6 @@ DirCache = {}
 
 
 def Run(options):
-    # logging.basicConfig(level=logging.INFO)
-
     path_prefix = ''
     m = re.search(r'(.*?)/share/gtk-doc/html', options.html_dir)
     if m:
@@ -72,7 +70,7 @@ def Run(options):
     # We scan the directory containing GLib and any directories in GNOME2_PATH
     # first, but these will be overriden by any later scans.
     dir = common.GetModuleDocDir('glib-2.0')
-    if os.path.exists(dir):
+    if dir and os.path.exists(dir):
         # Some predefined link targets to get links into type hierarchies as these
         # have no targets. These are always absolute for now.
         Links['GBoxed'] = dir + '/gobject/gobject-Boxed-Types.html'
@@ -87,7 +85,7 @@ def Run(options):
     path = os.environ.get('GNOME2_PATH')
     if path:
         for dir in path.split(':'):
-            dir += '/share/gtk-doc/html'
+            dir += 'share/gtk-doc/html'
             if os.path.exists(dir) and dir != options.html_dir:
                 logging.info('Scanning GNOME2_PATH directory: %s', dir)
                 ScanIndices(dir, (re.search(prefix_match, dir) is None))
@@ -144,7 +142,7 @@ gunzip %s
         elif entry.endswith('.devhelp2.gz') and not os.path.exists(full_entry[:-3]):
             # debian/ubuntu started to compress this as *devhelp2.gz :/
             print('''Please fix https://bugs.launchpad.net/ubuntu/+source/gtk-doc/+bug/1466210 . For now run:
-gunzip %d
+gunzip %s
 ''' % full_entry)
         # we could consider supporting: gzip module
 
@@ -175,7 +173,7 @@ def ReadDevhelp(file, use_absolute_links):
 
     logging.info('Scanning index file=%s, absolute=%d, dir=%s', file, use_absolute_links, dir)
 
-    for line in open(file):
+    for line in common.open_text(file):
         m = re.search(r' link="([^#]*)#([^"]*)"', line)
         if m:
             link = m.group(1) + '#' + m.group(2)
@@ -184,7 +182,7 @@ def ReadDevhelp(file, use_absolute_links):
 
 
 def ReadSections(options):
-    for line in open(options.module + '-sections.txt'):
+    for line in common.open_text(options.module + '-sections.txt'):
         m1 = re.search(r'^<SUBSECTION\s*(.*)>', line)
         if line.startswith('#') or line.strip() == '':
             continue
@@ -220,9 +218,7 @@ def FixCrossReferences(options):
 def FixHTMLFile(options, file):
     logging.info('Fixing file: %s', file)
 
-    content = open(file).read()
-    if sys.version_info < (3,):
-        content = content.decode('utf-8')
+    content = common.open_text(file).read()
 
     if config.highlight:
         # FIXME: ideally we'd pass a clue about the example language to the highligher
@@ -266,9 +262,8 @@ def FixHTMLFile(options, file):
 
     new_file = file + '.new'
     content = '\n'.join(lines)
-    if sys.version_info < (3,):
-        content = content.encode('utf-8')
-    open(new_file, 'w').write(content)
+    with common.open_text(new_file, 'w') as h:
+        h.write(content)
 
     os.unlink(file)
     os.rename(new_file, file)
@@ -376,14 +371,14 @@ def HighlightSourceVim(options, type, source):
 
         # format source
         # TODO(ensonic): use p.communicate()
-        script = "echo 'let html_number_lines=0|let html_use_css=1|let html_use_xhtml=1|e %s|syn on|set syntax=%s|run! syntax/2html.vim|w! %s.html|qa!' | " % (
+        script = "echo 'let html_number_lines=0|let html_use_css=1|let html_use_xhtml=1|e %s|syn on|set syntax=%s|run! plugin/tohtml.vim|run! syntax/2html.vim|w! out.html|qa!' | " % (
             temp_source_file, options.src_lang, temp_source_file)
         script += "%s -n -e -u NONE -T xterm >/dev/null" % config.highlight
         subprocess.check_call([script], shell=True)
 
-        highlighted_source = open(temp_source_file + ".html").read()
-        highlighted_source = re.sub(r'.*<pre\b[^>]*>\n', '', highlighted_source, flags=re.MULTILINE)
-        highlighted_source = re.sub(r'</pre>.*', '', highlighted_source, flags=re.MULTILINE)
+        highlighted_source = common.open_text(temp_source_file + ".html").read()
+        highlighted_source = re.sub(r'.*<pre\b[^>]*>\n', '', highlighted_source, flags=re.DOTALL)
+        highlighted_source = re.sub(r'</pre>.*', '', highlighted_source, flags=re.DOTALL)
 
         # need to rewrite the stylesheet classes
         highlighted_source = highlighted_source.replace('<span class="Comment">', '<span class="comment">')
