@@ -168,9 +168,6 @@
  * This file contains non-sense code for the sole purpose of testing the docs.
  */
 
-#include <glib.h>
-#include <glib-object.h>
-
 #include "gobject.h"
 #include "giface.h"
 
